<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :xl="5" :lg="6" :md="8" :sm="12">
            <a-form-item label="统一编码">
              <technical-status-equipment-select placeholder="请输入统一编码或名称搜索"
                                                 v-model="queryParam.equipmentId" />
            </a-form-item>
          </a-col>
          <a-col :xl="5" :lg="6" :md="8" :sm="12">
            <a-form-item label="工单号">
              <a-input placeholder="请输入工单号" v-model="queryParam.orderNum" />
            </a-form-item>
          </a-col>
          <a-col :xl="5" :lg="6" :md="8" :sm="12">
            <a-form-item label="计划鉴定日期">
              <a-date-picker v-model="queryParam.evaluationDate" style="width: 100%" />
            </a-form-item>
          </a-col>
          <a-col :xl="4" :lg="6" :md="8" :sm="12">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="info" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
    </div>

    <!-- table区域-begin -->
    <a-table bordered rowKey="id" :columns="columns" :dataSource="dataSource" :pagination="ipagination"
             :scroll="{ x: 'max-content' }" :loading="loading" @change="handleTableChange">

        <span slot="action" slot-scope="text, record">
          <a-popconfirm v-if="record.evaluationStatus === 'WAIT_EVALUATION'" title="确定领取吗？"
                        @confirm="handleReceive(record.id)">
            <a>领取</a>
          </a-popconfirm>
        </span>
    </a-table>
    <!-- table区域-end -->

    <!-- 表单区域 -->
    <eamTechnicalStatusEvaluationOrder-modal ref="modalForm" @ok="modalFormOk" />
  </a-card>
</template>

<script>
import EamTechnicalStatusEvaluationOrderModal from './modules/EamTechnicalStatusEvaluationOrderModal'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import TechnicalStatusEquipmentSelect from '../equipment/modules/TechnicalStatusEquipmentSelect'
import { getAction } from '@/api/manage'

export default {
  name: 'EamTechnicalStatusEvaluationOrderList',
  mixins: [JeecgListMixin],
  components: {
    TechnicalStatusEquipmentSelect,
    EamTechnicalStatusEvaluationOrderModal
  },
  data() {
    return {
      description: '技术状态鉴定工单管理页面',
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          },
          fixed: 'left'
        },
        {
          title: '统一编码',
          align: 'center',
          dataIndex: 'equipmentCode',
          fixed: 'left'
        },
        {
          title: '设备名称',
          align: 'center',
          dataIndex: 'equipmentName',
          fixed: 'left'
        },
        {
          title: '设备型号',
          align: 'center',
          dataIndex: 'equipmentModel',
          fixed: 'left'
        },
        {
          title: '工单号',
          align: 'center',
          dataIndex: 'orderNum',
          fixed: 'left'
        },
        {
          title: '计划鉴定日期',
          align: 'center',
          dataIndex: 'evaluationDate',
          fixed: 'left'
        },
        {
          title: '锁定工单日期',
          align: 'center',
          dataIndex: 'freezeOrderDate'
        },
        {
          title: '工单过期日期',
          align: 'center',
          dataIndex: 'orderExpirationDate'
        },
        {
          title: '实际开始时间',
          align: 'center',
          dataIndex: 'actualStartTime'
        },
        {
          title: '实际结束时间',
          align: 'center',
          dataIndex: 'actualEndTime'
        },
        {
          title: '鉴定人',
          align: 'center',
          dataIndex: 'evaluator'
        },
        {
          title: '鉴定状态',
          align: 'center',
          dataIndex: 'evaluationStatus_dictText'
        },
        {
          title: '创建方式',
          align: 'center',
          dataIndex: 'creationMethod_dictText'
        },
        {
          title: '安全装置检查结果',
          align: 'center',
          dataIndex: 'safetyEquipmentCheckResult'
        },
        {
          title: '精度参数检查结果',
          align: 'center',
          dataIndex: 'precisionCheckResult'
        },
        {
          title: '功能状态检查结果',
          align: 'center',
          dataIndex: 'functionalCheckResult'
        },
        {
          title: '其他检查结果',
          align: 'center',
          dataIndex: 'otherCheckResult'
        },
        {
          title: '维修室主任签字',
          align: 'center',
          dataIndex: 'repairManagerSignature'
        },
        {
          title: '维修室主任签字时间',
          align: 'center',
          dataIndex: 'repairManagerSignatureTime1'
        },
        {
          title: '试件检查结果',
          align: 'center',
          dataIndex: 'sampleCheckResult'
        },
        {
          title: '工艺员签字',
          align: 'center',
          dataIndex: 'processTechnicianSignature'
        },
        {
          title: '工艺员签字时间',
          align: 'center',
          dataIndex: 'processTechnicianSignatureTime'
        },
        {
          title: '鉴定结果',
          align: 'center',
          dataIndex: 'evaluationResult'
        },
        {
          title: '限/禁用原因',
          align: 'center',
          dataIndex: 'evaluationReason'
        },
        {
          title: '设备检查人签字',
          align: 'center',
          dataIndex: 'inspectorSignature'
        },
        {
          title: '设备检查人签字时间',
          align: 'center',
          dataIndex: 'inspectorSignatureTime'
        },
        {
          title: '附录A HF编码',
          align: 'center',
          dataIndex: 'hfCodeA'
        },
        {
          title: '附录B HF编码',
          align: 'center',
          dataIndex: 'hfCodeB'
        },
        {
          title: '附录C HF编码',
          align: 'center',
          dataIndex: 'hfCodeC'
        },
        {
          title: '附录D HF编码',
          align: 'center',
          dataIndex: 'hfCodeD'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: 'center',
          scopedSlots: { customRender: 'action' },
          fixed: 'right'
        }
      ],
      url: {
        list: '/eam/eamTechnicalStatusEvaluationOrder/list',
        receive: '/eam/eamTechnicalStatusEvaluationOrder/collect',
      }
    }
  },
  computed: {
  },
  methods: {
    handleReceive(id) {
      let that = this
      this.loading = true
      getAction(that.url.receive, { id })
        .then(res => {
          if (res.success) {
            that.$notification.success({
              message: '消息',
              description: res.message
            })
            that.loadData();
          } else {
            that.$notification.warning({
              message: '消息',
              description: res.message
            })
            that.loading = false
          }
        })
    }
  }
}
</script>